@@ -8,7 +8,7 @@ import boto3
 import moto
 import pytest
 from aswan.constants import DEFAULT_REMOTE_ENV_VAR, DEPOT_ROOT_ENV_VAR
-from aswan.depot import HEX_ENV, PW_ENV
+from aswan.depot.remote import HEX_ENV, PW_ENV
 from dvc.config import Config as DvcConfig
 from zimmauth import ZimmAuth
 from zimmauth.core import LOCAL_HOST_NAMES_ENV_VAR
@@ -19,11 +19,11 @@ from datazimmer.naming import (
     AUTH_PASS_ENV_VAR,
     DEFAULT_ENV_NAME,
     MAIN_MODULE_NAME,
-    TEMPLATE_REPO,
 )
 from datazimmer.tests.create_dogshow import dogshow_root
-from datazimmer.typer_commands import cleanup
-from datazimmer.utils import cd_into, gen_rmtree, git_run
+from datazimmer.tests.util import dz_ctx
+from datazimmer.typer_commands import cleanup, init, init_explorer
+from datazimmer.utils import cd_into, gen_rmtree
 
 CORE_PY = dogshow_root / "minimal.py"
 
@@ -35,26 +35,36 @@ def pytest_addoption(parser):
 
 @pytest.fixture(scope="session")
 def empty_template():
-    tmpdir = TemporaryDirectory().name
-    git_run(clone=(TEMPLATE_REPO, tmpdir))
-    with cd_into(tmpdir):
-        check_call(["dvc", "remote", "add", "testrem", "/nothing"])
+    _tmp = TemporaryDirectory()
+    tmp_dir = Path(_tmp.name)
+    dvc_rem = tmp_dir / "dvc-rem"
+    pname = "test-project"
+    with cd_into(tmp_dir):
+        check_call(["git", "init", "remote"])
+        init(pname, git_remote=(tmp_dir / "remote").as_posix())
+    pdir = tmp_dir / pname
+    with cd_into(pdir):
+        check_call(["dvc", "remote", "add", "testrem", dvc_rem.as_posix()])
         check_call(["dvc", "remote", "default", "testrem"])
         Path(MAIN_MODULE_NAME, "core.py").write_text(CORE_PY.read_text())
-    yield tmpdir
-    with cd_into(tmpdir):
-        cleanup()
-    gen_rmtree(tmpdir)
+    with dz_ctx([pdir]):
+        yield pdir
+    gen_rmtree(tmp_dir)
 
 
 @pytest.fixture
-def in_template(empty_template):
+def in_template(empty_template: Path):
     with cd_into(empty_template):
-        sys.path.insert(0, empty_template)
-        yield
+        sys.path.insert(0, empty_template.as_posix())
+        yield empty_template
         sys.path.pop(0)
 
 
+@pytest.fixture(scope="session")
+def small_explorer():
+    pass
+
+
 @pytest.fixture
 def running_template(in_template):
     _env = DEFAULT_ENV_NAME
