@@ -12,9 +12,9 @@ from structlog import get_logger
 
 from ..config_loading import RunConfig
 from ..get_runtime import get_runtime
-from ..metadata.atoms import EntityClass
+from ..metadata.atoms import EntityClass, feats_to_cols, to_sa_col
 from ..metadata.high_level import NamespaceMetadata
-from ..metadata.scrutable import ScruTable, feats_to_cols, to_sa_col
+from ..metadata.scrutable import ScruTable
 from ..utils import is_postgres
 
 if TYPE_CHECKING:
@@ -43,7 +43,7 @@ class SqlLoader:
 
         self.runtime = get_runtime()
         self.engine = sa.create_engine(constr, echo=echo)
-        self.sql_meta = sa.MetaData()
+        self.sql_meta = sa.MetaData(bind=self.engine)
         self._Session = sessionmaker(self.engine)
         self._batch_size = batch_size
 
@@ -140,7 +140,7 @@ class NamespaceMapper:
                 for _df in [df, df_sql]
             ]
         if df.empty and df_sql.empty:
-            logger.warn("empty data frames", table=table_id)
+            logger.warning("empty data frames", table=table_id)
 
         pd.testing.assert_frame_equal(df.loc[:, df_sql.columns], df_sql)
 
