@@ -1,9 +1,13 @@
 import pandas as pd
 import pytest
+import sqlalchemy as sa
 
 from datazimmer import ScruTable
+from datazimmer.config_loading import RunConfig
 from datazimmer.exceptions import ProjectSetupException
+from datazimmer.get_runtime import get_runtime
 from datazimmer.naming import DEFAULT_ENV_NAME
+from datazimmer.sql.loader import SqlLoader, tmp_constr
 
 
 def test_scrutable_parsing(running_template):
@@ -46,3 +50,15 @@ def test_run_scrutable(in_template):
 
     with pytest.raises(ProjectSetupException):
         scrutable.replace_all(...)
+
+
+def test_sql(in_template):
+    runtime = get_runtime()
+    with RunConfig(False, write_env=DEFAULT_ENV_NAME, read_env=DEFAULT_ENV_NAME):
+        runtime.run_step("core", DEFAULT_ENV_NAME)
+
+    with tmp_constr() as constr:
+        loader = SqlLoader(constr)
+        sa.MetaData.reflect(loader.sql_meta)
+        loader.load_data(DEFAULT_ENV_NAME)
+        loader.validate_data(DEFAULT_ENV_NAME)
