@@ -1,7 +1,7 @@
 import datazimmer as dz
 
-from .counts.meta import SizeCountFeatures, size_count_table
-from .sex_matches import SexMatchFeatures, sex_match_table
+from .counts.meta import SizeCount, size_count_table
+from .sex_matches import SexMatch, sex_match_table
 
 top_tables_report = dz.ReportFile("tops.md")
 deps = [sex_match_table, size_count_table]
@@ -10,11 +10,9 @@ deps = [sex_match_table, size_count_table]
 @dz.register(dependencies=deps, outputs_nocache=[top_tables_report])  # remove in v1.0
 def calculate_sex_match(show_top):
 
-    sm_df = sex_match_table.get_full_df().sort_values(
-        SexMatchFeatures.count, ascending=False
-    )
+    sm_df = sex_match_table.get_full_df().sort_values(SexMatch.count, ascending=False)
     sc_df = size_count_table.get_full_df().sort_values(
-        SizeCountFeatures.elem_count, ascending=False
+        SizeCount.elem_count, ascending=False
     )
 
     top_tables_report.write_text(
